==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Web/Gui/Resources/translations/Web_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>上一頁</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>回到上一頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>下一頁</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>前進下一頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>更新網頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>停止載入</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>停止目前載入動作</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>放大</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>放大頁面</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>縮小</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>縮小頁面</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>開啟網頁...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>於FreeCAD中開啟網頁</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation type="unfinished">Sketchfab exporter</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation type="unfinished">What to upload?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>選擇</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation type="unfinished">All visible objects</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation type="unfinished">Model name</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation type="unfinished">Private</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>說明</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation type="unfinished">Tags (separated by commas)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation type="unfinished">FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation type="unfinished">Format</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation type="unfinished">OBJ + MTL (Arch exporter)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation type="unfinished">OBJ (standard Mesh exporter)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation type="unfinished">DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation type="unfinished">STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation type="unfinished">IGES (shapes only)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation type="unfinished">IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation type="unfinished">Sketchfab API token</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation type="unfinished">Obtain</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation type="unfinished">Upload</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation type="unfinished">uploading</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation type="unfinished">Success! View uploaded online</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="412"/>
      <source>Browser</source>
      <translation>瀏覽器</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="309"/>
      <source>File does not exist!</source>
      <translation>檔案不存在!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="304"/>
      <source>Error</source>
      <translation>錯誤</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="383"/>
      <source>Loading %1...</source>
      <translation>載入 %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="181"/>
      <source>Open in External Browser</source>
      <translation>於外部瀏覽器開啟</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in new window</source>
      <translation>於新視窗中開啟</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>導覽</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Web/Gui/Resources/translations/Web_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>上一頁</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>回到上一頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>下一頁</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>前進下一頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>更新網頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>停止載入</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>停止目前載入動作</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>放大</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>放大頁面</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>縮小</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>縮小頁面</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>開啟網頁...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>於FreeCAD中開啟網頁</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation>Sketchfab 輸出產生器</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation>要上傳什麼呢？</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>選擇</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation>所有可見物件</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation>模型名稱</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation>私人</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>說明</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation>標籤 (以逗號分隔)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation>FreeCAD</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation>格式</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation>OBJ + MTL (建築模組輸出產生器)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation>OBJ (標準網格輸出產生器)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation>DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation>STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation>IGES (僅造型)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation>IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation>Sketchfab API代碼</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation>獲取</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation type="unfinished">Upload</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation>上傳中</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation>成功！線上查看已上傳清單</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="440"/>
      <source>Browser</source>
      <translation>瀏覽器</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="337"/>
      <source>File does not exist!</source>
      <translation>檔案不存在!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="329"/>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>Error</source>
      <translation>錯誤</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation type="unfinished">There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="411"/>
      <source>Loading %1...</source>
      <translation>載入 %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in External Browser</source>
      <translation>於外部瀏覽器開啟</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="189"/>
      <source>Open in new window</source>
      <translation>於新視窗中開啟</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>導覽</translation>
    </message>
  </context>
</TS>
